Struct Chain

pub struct Chain<A, B> { /* private fields */ }
The chain adapter.

See: Buf::chain and BufMut::chain.

Implementations

Source

impl<A, B> Chain<A, B>

pub fn first(&self) -> &A

Get a reference to the first buffer in the chain.

pub fn first_mut(&mut self) -> &mut A

Get a mutable reference to the first buffer in the chain.

pub fn second(&self) -> &B

Get a reference to the second buffer in the chain.

pub fn second_mut(&mut self) -> &mut B

Get a mutable reference to the second buffer in the chain.

pub fn into_first(self) -> A

Destruct the adapter and get back the first buffer.

pub fn into_second(self) -> B

Destruct the adapter and get back the second buffer.

pub fn into_inner(self) -> (A, B)

Destruct the adapter and get back both buffers.