pub struct Config { /* private fields */ }Expand description
Configuration for Receiver.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn set_max_size(&mut self, max_size: usize) -> &mut Self
pub fn set_max_size(&mut self, max_size: usize) -> &mut Self
Set the max payload size the Receiver will accept.
Sourcepub fn with_max_size(self, max_size: usize) -> Self
pub fn with_max_size(self, max_size: usize) -> Self
Set the max payload size the Receiver will accept.
Sourcepub fn verify_order(&self) -> bool
pub fn verify_order(&self) -> bool
Check whether the Receiver will verify the order of received frames.
Sourcepub fn set_verify_order(&mut self, yes: bool) -> &mut Self
pub fn set_verify_order(&mut self, yes: bool) -> &mut Self
Set whether the Receiver will verify the order of received frames.
Sourcepub fn with_verify_order(self, yes: bool) -> Self
pub fn with_verify_order(self, yes: bool) -> Self
Set whether the Receiver will verify the order of received frames.