pub enum DeserializeError<T> {
InvalidChecksum,
NoChecksum,
Next(T),
}Expand description
Possible errors that might occur during deserialization.
Variants
InvalidChecksum
The data could not be verified because the checksum is not correct.
NoChecksum
No checksum exists in the data.
Next(T)
An error from the next deserializer in the chain.