pub struct Chain<A, B> { /* private fields */ }Expand description
The chain adapter.
See: Buf::chain and BufMut::chain.
Implementations
Sourceimpl<A, B> Chain<A, B>
impl<A, B> Chain<A, B>
Sourcepub fn first_mut(&mut self) -> &mut A
pub fn first_mut(&mut self) -> &mut A
Get a mutable reference to the first buffer in the chain.
Sourcepub fn second_mut(&mut self) -> &mut B
pub fn second_mut(&mut self) -> &mut B
Get a mutable reference to the second buffer in the chain.
Sourcepub fn into_first(self) -> A
pub fn into_first(self) -> A
Destruct the adapter and get back the first buffer.
Sourcepub fn into_second(self) -> B
pub fn into_second(self) -> B
Destruct the adapter and get back the second buffer.
Sourcepub fn into_inner(self) -> (A, B)
pub fn into_inner(self) -> (A, B)
Destruct the adapter and get back both buffers.